# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/mbl_market_book_updates.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import side_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/type/shared/v1/mbl_market_book_updates.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-systemathics/apis/type/shared/v1/action.proto\x1a+systemathics/apis/type/shared/v1/side.proto\"\xd2\x01\n\x14MblMarketBookUpdates\x12\x18\n\x07mapping\x18\x01 \x01(\rR\x07mapping\x12\x39\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05reset\x18\x03 \x01(\x08R\x05reset\x12O\n\x07updates\x18\x04 \x03(\x0b\x32\x35.systemathics.apis.type.shared.v1.MblMarketBookUpdateR\x07updates\"\x8e\x02\n\x13MblMarketBookUpdate\x12@\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.ActionR\x06\x61\x63tion\x12:\n\x04side\x18\x02 \x01(\x0e\x32&.systemathics.apis.type.shared.v1.SideR\x04side\x12\x14\n\x05\x64\x65pth\x18\x03 \x01(\rR\x05\x64\x65pth\x12/\n\x04size\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x04size\x12\x32\n\x05price\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05priceB\xe6\x01\n$com.systemathics.apis.type.shared.v1B\x19MblMarketBookUpdatesProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.mbl_market_book_updates_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\031MblMarketBookUpdatesProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_MBLMARKETBOOKUPDATES']._serialized_start=258
  _globals['_MBLMARKETBOOKUPDATES']._serialized_end=468
  _globals['_MBLMARKETBOOKUPDATE']._serialized_start=471
  _globals['_MBLMARKETBOOKUPDATE']._serialized_end=741
# @@protoc_insertion_point(module_scope)
