# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/dividends.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/corporate_actions/v1/dividends.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xb5\x01\n\x10\x44ividendsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"b\n\x11\x44ividendsResponse\x12M\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x39.systemathics.apis.services.corporate_actions.v1.DividendR\x04\x64\x61ta\"\xb2\x01\n\x08\x44ividend\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12Q\n\x04type\x18\x02 \x01(\x0e\x32=.systemathics.apis.services.corporate_actions.v1.DividendTypeR\x04type\x12\x16\n\x06\x61mount\x18\x03 \x01(\x01R\x06\x61mount\x12\x14\n\x05score\x18\x04 \x01(\x01R\x05score*^\n\x0c\x44ividendType\x12\x1d\n\x19\x44IVIDEND_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x44IVIDEND_TYPE_CASH\x10\x01\x12\x17\n\x13\x44IVIDEND_TYPE_STOCK\x10\x02\x32\xd0\x01\n\x10\x44ividendsService\x12\xbb\x01\n\tDividends\x12\x41.systemathics.apis.services.corporate_actions.v1.DividendsRequest\x1a\x42.systemathics.apis.services.corporate_actions.v1.DividendsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/corporate-actions/dividendsB\xa2\x02\n3com.systemathics.apis.services.corporate_actions.v1B\x0e\x44ividendsProtoP\x01\xa2\x02\x04SASC\xaa\x02.Systemathics.Apis.Services.CorporateActions.V1\xca\x02.Systemathics\\Apis\\Services\\CorporateActions\\V1\xe2\x02:Systemathics\\Apis\\Services\\CorporateActions\\V1\\GPBMetadata\xea\x02\x32Systemathics::Apis::Services::CorporateActions::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.corporate_actions.v1.dividends_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3com.systemathics.apis.services.corporate_actions.v1B\016DividendsProtoP\001\242\002\004SASC\252\002.Systemathics.Apis.Services.CorporateActions.V1\312\002.Systemathics\\Apis\\Services\\CorporateActions\\V1\342\002:Systemathics\\Apis\\Services\\CorporateActions\\V1\\GPBMetadata\352\0022Systemathics::Apis::Services::CorporateActions::V1'
  _globals['_DIVIDENDSSERVICE'].methods_by_name['Dividends']._options = None
  _globals['_DIVIDENDSSERVICE'].methods_by_name['Dividends']._serialized_options = b'\202\323\344\223\002!\022\037/v1/corporate-actions/dividends'
  _globals['_DIVIDENDTYPE']._serialized_start=740
  _globals['_DIVIDENDTYPE']._serialized_end=834
  _globals['_DIVIDENDSREQUEST']._serialized_start=276
  _globals['_DIVIDENDSREQUEST']._serialized_end=457
  _globals['_DIVIDENDSRESPONSE']._serialized_start=459
  _globals['_DIVIDENDSRESPONSE']._serialized_end=557
  _globals['_DIVIDEND']._serialized_start=560
  _globals['_DIVIDEND']._serialized_end=738
  _globals['_DIVIDENDSSERVICE']._serialized_start=837
  _globals['_DIVIDENDSSERVICE']._serialized_end=1045
# @@protoc_insertion_point(module_scope)
